@@ -32,7 +32,7 @@
 class DialogExternalVideoPreferences : public Gtk::Dialog
 {
 public:
-	DialogExternalVideoPreferences(BaseObjectType *cobject, const Glib::RefPtr<Gnome::Glade::Xml>& xml)
+	DialogExternalVideoPreferences(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder>& xml)
 	:Gtk::Dialog(cobject)
 	{
 		Gtk::Entry* entry = NULL;
@@ -44,8 +44,8 @@ public:
 	{
 		std::auto_ptr<DialogExternalVideoPreferences> dialog(
 				gtkmm_utility::get_widget_derived<DialogExternalVideoPreferences>(
-						SE_DEV_VALUE(SE_PLUGIN_PATH_GLADE, SE_PLUGIN_PATH_DEV),
-						"dialog-external-video-player-preferences.glade", 
+						SE_DEV_VALUE(SE_PLUGIN_PATH_UI, SE_PLUGIN_PATH_DEV),
+						"dialog-external-video-player-preferences.ui", 
 						"dialog-external-video-player-preferences"));
 
 		dialog->run();
@@ -184,7 +184,7 @@ public:
 		// save now tmp subtitle
 		Glib::ustring old_filename = doc->getFilename();
 
-		doc->save(subtitle_file);
+		doc->save(Glib::filename_to_uri(subtitle_file));
 		doc->setFilename(old_filename);
 	
 		long start_position = 0;
