@@ -24,7 +24,7 @@
 #include <utility.h>
 #include <gui/dialogfilechooser.h>
 #include <filereader.h>
-#include <filewriter.h>
+#include <subtitleformatsystem.h>
 
 /*
  *
@@ -54,7 +54,8 @@ public:
 		action_group = Gtk::ActionGroup::create("PlainTextPlugin");
 
 		action_group->add(
-				Gtk::Action::create("plain-text-import", _("_Import Plain Text"), _("Create a new document with any text file")),
+				Gtk::Action::create("plain-text-import", _("_Import Plain Text"),
+						_("Create a new document from any text file.")),
 					sigc::mem_fun(*this, &PlainTextPlugin::on_import_transcript));
 
 		action_group->add(
@@ -114,28 +115,16 @@ protected:
 			try
 			{
 				Glib::ustring untitled = DocumentSystem::getInstance().create_untitled_name();
-
 				Document *doc = new Document();
-				
-				FileReader file(uri, charset);
-
-				Subtitles subtitles = doc->subtitles();
-
-				Glib::ustring line;
-				while(file.getline(line))
-				{
-					Subtitle sub = subtitles.append();
-					sub.set_text(line);
-				}
-
-				doc->setCharset(file.get_charset());
+				SubtitleFormatSystem::instance().open_from_uri(doc, uri, charset, "Plain Text Format");
 				doc->setName(untitled);
 				DocumentSystem::getInstance().append(doc);
+				
 			}
 			catch(const std::exception &ex)
 			{
 				dialog_error(
-						build_message(_("Could not import from the file \"%s\"."), uri.c_str()), 
+						build_message(_("Could not import from file \"%s\"."), uri.c_str()), 
 						ex.what());
 			}
 		}
@@ -157,16 +146,8 @@ protected:
 
 			try
 			{
-				FileWriter file(uri, charset, newline);
-
 				Document *doc = get_current_document();
-
-				for(Subtitle sub = doc->subtitles().get_first(); sub; ++sub)
-				{
-					file.write(sub.get_text() + "\n");
-				}
-
-				file.to_file();
+				SubtitleFormatSystem::instance().save_to_uri( doc, uri, "Plain Text Format", charset, newline );
 			}
 			catch(const std::exception &ex)
 			{
