@@ -45,7 +45,7 @@ class ComboBoxOutput : public Gtk::ComboBox
 public:
 	/*
 	 */
-	ComboBoxOutput(BaseObjectType *cobject, const Glib::RefPtr<Gnome::Glade::Xml>& xml)
+	ComboBoxOutput(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder>& xml)
 	:Gtk::ComboBox(cobject)
 	{
 		m_model = Gtk::ListStore::create(m_column);
@@ -105,7 +105,7 @@ public:
 	/*
 	 *
 	 */
-	VideoPlayerPage(BaseObjectType *cobject, const Glib::RefPtr<Gnome::Glade::Xml>& xml)
+	VideoPlayerPage(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder>& xml)
 	:PreferencePage(cobject)
 	{
 		init_widget(xml, "fontbutton-subtitle", "video-player", "font-desc");
@@ -127,6 +127,9 @@ public:
 		m_comboAudioOutput->append_output(_("OSS - Open Sound System"), "osssink");
 		m_comboAudioOutput->append_output(_("SDL - Simple DirectMedia Layer"), "sdlaudiosink");
 		m_comboAudioOutput->append_output(_("GConf"), "gconfaudiosink");
+#ifdef USE_OSX
+		m_comboAudioOutput->append_output(_("OSX"), "osxaudiosink");
+#endif
 
 		// video output
 		m_comboVideoOutput->append_output(_("Autodetect"), "autovideosink");
@@ -135,6 +138,9 @@ public:
 		m_comboVideoOutput->append_output(_("SDL - Simple DirectMedia Layer"), "sdlvideosink");
 		m_comboVideoOutput->append_output(_("GConf"), "gconfvideosink");
 		m_comboVideoOutput->append_output(_("OpenGL"), "glimagesink");
+#ifdef USE_OSX
+		m_comboVideoOutput->append_output(_("OSX"), "osxvideosink");
+#endif
 
 		Glib::ustring audiosink = Config::getInstance().get_value_string("video-player", "audio-sink");
 		Glib::ustring videosink = Config::getInstance().get_value_string("video-player", "video-sink");
