@@ -321,7 +321,7 @@ public:
 	/*
 	 *
 	 */
-	void open(FileReader &file)
+	void open(Reader &file)
 	{
 		std::vector<Glib::ustring> lines = file.get_lines();
 
@@ -334,7 +334,7 @@ public:
 	/*
 	 *
 	 */
-	void save(FileWriter &file)
+	void save(Writer &file)
 	{
 		write_script_info(file);
 		write_styles(file);
@@ -344,7 +344,7 @@ public:
 	/*
 	 *
 	 */
-	void write_script_info(FileWriter &file)
+	void write_script_info(Writer &file)
 	{
 		file.write(
 			Glib::ustring::compose(
@@ -371,7 +371,7 @@ public:
 	/*
 	 *
 	 */
-	void write_styles(FileWriter &file)
+	void write_styles(Writer &file)
 	{
 		file.write("[V4 Styles]\n");
 		file.write(
@@ -442,7 +442,7 @@ public:
 	/*
 	 * Write the block [Events]
 	 */
-	void write_events(FileWriter &file)
+	void write_events(Writer &file)
 	{
 		file.write("[Events]\n");
 		// format:
