@@ -23,28 +23,36 @@
  *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <gtkmm/comboboxtext.h>
-#include <libglademm/xml.h>
+#include <gtkmm/builder.h>
 #include "debug.h"
+#include <iostream>
 
 namespace gtkmm_utility {
 
 /*
- * Create and return a widget derived from glade file.
+ * Create and return a widget derived from ui file.
  */
 template<class T>
-T* get_widget_derived(const Glib::ustring &path, const Glib::ustring &glade_file, const Glib::ustring &name)
+T* get_widget_derived(const Glib::ustring &path, const Glib::ustring &ui_file, const Glib::ustring &name)
 {
-	se_debug_message(SE_DEBUG_UTILITY, "glade_file=<%s> name=<%s>", glade_file.c_str(), name.c_str());
+	se_debug_message(SE_DEBUG_UTILITY, "ui_file=<%s> name=<%s>", ui_file.c_str(), name.c_str());
 
 	T *dialog = NULL;
 
-	Glib::ustring file = Glib::build_filename(path, glade_file);
+	try
+	{
+		Glib::ustring file = Glib::build_filename(path, ui_file);
 
-	Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(file);
+		Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(file);
 
-	refXml->get_widget_derived(name, dialog);
-	return dialog;
+		refXml->get_widget_derived(name, dialog);
+		return dialog;
+	}
+	catch(const Glib::Error &ex)
+	{
+		std::cerr << "get_widget_derived failed: " << ex.what() << std::endl;
+	}
+	return NULL;
 }
 
 }//namespace gtkmm_utility
