@@ -348,7 +348,7 @@ DialogSaveDocument::auto_ptr DialogSaveDocument::create()
 }
 
 /*
- * DialogExportText
+ * DialogImportText
  * Dialog open file chooser with Encoding option.
  */
 
@@ -359,10 +359,12 @@ DialogImportText::DialogImportText(BaseObjectType* cobject, const Glib::RefPtr<G
 :DialogFileChooser(cobject, "dialog-import-text")
 {
 	builder->get_widget_derived("combobox-encodings", m_comboEncodings);
+	builder->get_widget("checkbutton-blank-lines", m_checkBlankLines);
+	widget_config::read_config_and_connect(m_checkBlankLines, "plain-text", "import-bl-between-subtitles");
 
 	add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
 	add_button(Gtk::Stock::OPEN, Gtk::RESPONSE_OK);
-	
+
 	set_default_response(Gtk::RESPONSE_OK);
 }
 
@@ -375,6 +377,14 @@ Glib::ustring DialogImportText::get_encoding() const
 	return m_comboEncodings->get_value();
 }
 
+/*
+ * Returns whether blank lines separate subtitles
+ */
+bool DialogImportText::get_blank_line_mode() const
+{
+	return m_checkBlankLines->get_active();
+}
+
 /*
  * Create a instance of the dialog.
  */
@@ -404,6 +414,8 @@ DialogExportText::DialogExportText(BaseObjectType* cobject, const Glib::RefPtr<G
 {
 	builder->get_widget_derived("combobox-encodings", m_comboEncodings);
 	builder->get_widget_derived("combobox-newline", m_comboNewLine);
+	builder->get_widget("checkbutton-blank-lines", m_checkBlankLines);
+	widget_config::read_config_and_connect(m_checkBlankLines, "plain-text", "export-bl-between-subtitles");
 
 	m_comboEncodings->show_auto_detected(false);
 
@@ -430,6 +442,14 @@ Glib::ustring DialogExportText::get_newline() const
 	return m_comboNewLine->get_value();
 }
 
+/*
+ * Returns whether subtitles should be separated by blank lines
+ */
+bool DialogExportText::get_blank_line_mode() const
+{
+	return m_checkBlankLines->get_active();
+}
+
 /*
  * Create a instance of the dialog.
  */
