@@ -25,7 +25,7 @@
 
 #include <gtkmm.h>
 #include <gtkmm/scalebutton.h>
-#include <libglademm.h>
+#include <gtkmm/builder.h>
 #include "waveformrenderer.h"
 #include "player.h"
 #include "waveformmanager.h"
@@ -40,7 +40,7 @@ public:
 	/*
 	 *
 	 */
-	WaveformEditor(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+	WaveformEditor(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
 
 	/*
 	 *
@@ -52,11 +52,6 @@ public:
 	 */
 	bool open_waveform(const Glib::ustring &uri);
 
-	/*
-	 * Try to generate a wavefrom from the media.
-	 */
-	bool generate_waveform(const Glib::ustring &media_uri);
-
 	/*
 	 * Init the Waveform Editor and the WaveformRenderer with this wf
 	 */
@@ -88,9 +83,8 @@ public:
 	Player* player();
 
 	/*
-	 *
 	 */
-	void on_player_timeout();
+	void on_player_tick(long current_time, long stream_length, double current_position);
 
 	/*
 	 * Return the current time of the player.
@@ -135,12 +129,12 @@ protected:
 	Gtk::Widget* create_control_widget();
 
 	/*
-	 * Enable the signal timeout (Player)
+	 * Enable the signal tick (Player)
 	 */
 	void on_map();
 
 	/*
-	 * Disable the signal timeout (Player).
+	 * Disable the signal tick (Player).
 	 */
 	void on_unmap();
 	
@@ -296,6 +290,12 @@ protected:
 	 */
 	void on_subtitle_time_changed();
 
+	/*
+	 * This callback is connected at the player.
+	 * The keyframes has changed, it's need to redraw the view.
+	 */
+	void on_player_message(Player::Message msg);
+
 	/*
 	 * Go at the position on the scrollbar. 
 	 * A little margin is added in the border.
@@ -360,7 +360,7 @@ protected:
 	bool m_cfg_respect_timing;
 
 	Player* m_player;
-	sigc::connection m_connection_timeout;
+	sigc::connection m_connection_player_tick;
 };
 
 
