@@ -23,6 +23,9 @@
 #include "utility.h"
 #include "document.h"
 #include "waveformrenderer.h"
+#include "subtitleeditorwindow.h"
+#include "keyframes.h"
+#include "player.h"
 
 #define TRIANGLE_SIZE 10
 
@@ -59,6 +62,12 @@ public:
 	 */
 	void waveform_changed();
 
+	/*
+	 * The keyframe is changed.
+	 * Need to redisplay the waveform.
+	 */
+	void keyframes_changed();
+
 	/*
 	 * Call queue_draw
 	 */
@@ -138,6 +147,10 @@ public:
 	 */
 	void display_time_info(Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &area);
 
+	/*
+	 */
+	void draw_keyframes(Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &area);
+
 protected:
 
 	Cairo::RefPtr<Cairo::Surface> m_wf_surface;
@@ -150,6 +163,7 @@ protected:
 WaveformRendererCairo::WaveformRendererCairo()
 :WaveformRenderer()
 {
+	se_debug(SE_DEBUG_WAVEFORM);
 }
 
 /*
@@ -157,6 +171,7 @@ WaveformRendererCairo::WaveformRendererCairo()
  */
 WaveformRendererCairo::~WaveformRendererCairo()
 {
+	se_debug(SE_DEBUG_WAVEFORM);
 }
 
 /*
@@ -164,6 +179,8 @@ WaveformRendererCairo::~WaveformRendererCairo()
  */
 Gtk::Widget* WaveformRendererCairo::widget()
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	return this;
 }
 
@@ -172,6 +189,8 @@ Gtk::Widget* WaveformRendererCairo::widget()
  */
 void WaveformRendererCairo::set_color(Cairo::RefPtr<Cairo::Context> &cr, float color[4])
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	cr->set_source_rgba(color[0], color[1], color[2], color[3]);
 }
 
@@ -181,16 +200,29 @@ void WaveformRendererCairo::set_color(Cairo::RefPtr<Cairo::Context> &cr, float c
  */
 void WaveformRendererCairo::waveform_changed()
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	if(m_wf_surface)
 		m_wf_surface.clear();
 	queue_draw();
 }
 
+/*
+ */
+void WaveformRendererCairo::keyframes_changed()
+{
+	se_debug(SE_DEBUG_WAVEFORM);
+
+	queue_draw();
+}
+
 /*
  * Call queue_draw
  */
 void WaveformRendererCairo::redraw_all()
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	queue_draw();
 }
 
@@ -199,6 +231,8 @@ void WaveformRendererCairo::redraw_all()
  */
 void WaveformRendererCairo::force_redraw_all()
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	if(m_wf_surface)
 		m_wf_surface.clear();
 	queue_draw();
@@ -228,6 +262,8 @@ bool WaveformRendererCairo::on_configure_event(GdkEventConfigure *ev)
  */
 bool WaveformRendererCairo::on_expose_event(GdkEventExpose *ev)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	static Glib::Timer m_timer;
 
 	// check minimum size
@@ -295,6 +331,8 @@ bool WaveformRendererCairo::on_expose_event(GdkEventExpose *ev)
 		cr->save();
 		cr->translate(-get_start_area(), 30);
 
+		draw_keyframes(cr, warea);
+
 		if(document())
 		{
 			draw_subtitles(cr, warea);
@@ -333,6 +371,8 @@ bool WaveformRendererCairo::on_expose_event(GdkEventExpose *ev)
  */
 void WaveformRendererCairo::draw_timeline(Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &area)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	// timeline
 	int width = area.get_width();
 	int height = area.get_height();
@@ -348,12 +388,19 @@ void WaveformRendererCairo::draw_timeline(Cairo::RefPtr<Cairo::Context> &cr, con
 	long sec_5 = SubtitleTime(0,0,5,0).totalmsecs;
 	long sec_10 = SubtitleTime(0,0,10,0).totalmsecs;
 
+	if(get_pos_by_time(sec_1) <= 0)
+		return;
 
 	Cairo::TextExtents extents;
 	cr->get_text_extents("0:00:00", extents);
-	
-	while(get_pos_by_time(sec_1) < extents.width + extents.width * 0.5)
+
+	float margin = extents.width + extents.width * 0.5;
+	while(get_pos_by_time(sec_1) < margin)
 	{
+		// for a sufficiently long duration sec_* will overflow before
+		// the loop terminates. check the largest of them.
+		if (sec_10 > (LONG_MAX/2))
+			break;
 		sec_1  *= 2;
 		sec_5  *= 2;
 		sec_10 *= 2;
@@ -371,6 +418,8 @@ void WaveformRendererCairo::draw_timeline(Cairo::RefPtr<Cairo::Context> &cr, con
  */
 void WaveformRendererCairo::draw_timeline_msecs(Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &area, long msec, int upper)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	int height = area.get_height();
 
 	int start_area = get_start_area();
@@ -397,6 +446,8 @@ void WaveformRendererCairo::draw_timeline_msecs(Cairo::RefPtr<Cairo::Context> &c
  */
 void WaveformRendererCairo::draw_timeline_time(Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &area, long msec)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	int start_area = get_start_area();
 
 	long start = get_time_by_pos(start_area);
@@ -432,6 +483,8 @@ void WaveformRendererCairo::draw_timeline_time(Cairo::RefPtr<Cairo::Context> &cr
  */
 void WaveformRendererCairo::draw_waveform(Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &area)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	if(!m_waveform)
 		return;
 
@@ -453,6 +506,8 @@ void WaveformRendererCairo::draw_waveform(Cairo::RefPtr<Cairo::Context> &cr, con
  */
 void WaveformRendererCairo::draw_channel(Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &area, unsigned int channel)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	if(!m_waveform)
 		return;
 
@@ -466,43 +521,40 @@ void WaveformRendererCairo::draw_channel(Cairo::RefPtr<Cairo::Context> &cr, cons
 
 	int width = get_width();
 
-	/*
-	double skip = (double)(width * zoom()) / peaks.size();
-
-	double x = 0;
-	
-	cr->move_to(0, bottom);
-	for(unsigned int i=0; i<peaks.size(); ++i, x+=skip)
-	{
-		double peakOnScreen = peaks[i] * scale_value;
-
-		peakOnScreen = CLAMP(peakOnScreen, 0, bottom);
-
-		cr->line_to(x, bottom - peakOnScreen);
-	}
-	cr->line_to(x, bottom);
-	cr->fill();
-	*/
+	se_debug_message(SE_DEBUG_WAVEFORM, "init drawing values");
 
 	double skip = 4;
+	int z = zoom();
 
-	double begin = peaks.size() * ((double)get_start_area() / (width * zoom()));
-	double move = peaks.size() * ((double)skip / (width * zoom()));
-	int lenght = width;
+	double begin = peaks.size() * ((double)get_start_area() / (width * z));
+	double move = peaks.size() * ((double)skip / (width * z));
+	int length = width;
+	int peaks_size = peaks.size();
 
 	double x = begin;
-	
+
+	se_debug_message(SE_DEBUG_WAVEFORM, 
+			"begin %f  move %f  length %d  peaks_size %d", 
+			begin, move, length, peaks_size);
+
+	se_debug_message(SE_DEBUG_WAVEFORM, "start drawing peaks");
+
 	cr->line_to(0, bottom);
-	for(int t=0; t<lenght; t+=skip, x+=move)
+	for(int t=0; t<length; t+=skip, x+=move)
 	{
-		double peakOnScreen = peaks[(int)x] * scale_value;
+		int px = (int)x;
+		if(px > peaks_size)
+			break;
+		double peakOnScreen = peaks[px] * scale_value;
 
 		peakOnScreen = CLAMP(peakOnScreen, 0, bottom);
 
 		cr->line_to(t, bottom - peakOnScreen);
 	}
-	cr->line_to(lenght, bottom);
+	cr->line_to(length, bottom);
 	cr->fill();
+
+	se_debug_message(SE_DEBUG_WAVEFORM, "end of drawing peaks");
 }
 
 /*
@@ -514,6 +566,8 @@ void WaveformRendererCairo::draw_channel(Cairo::RefPtr<Cairo::Context> &cr, cons
  */
 void WaveformRendererCairo::draw_subtitle_text(Cairo::RefPtr<Cairo::Context> &cr, const Subtitle &sub, int start, int end)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	cr->save();
 
 	cr->rectangle(start, 0, end - start, get_height());
@@ -540,6 +594,8 @@ void WaveformRendererCairo::draw_subtitle_text(Cairo::RefPtr<Cairo::Context> &cr
  */
 void WaveformRendererCairo::draw_subtitles(Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &area)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	if(!document())
 		return;
 
@@ -616,6 +672,8 @@ void WaveformRendererCairo::draw_subtitles(Cairo::RefPtr<Cairo::Context> &cr, co
  */
 void WaveformRendererCairo::draw_marker(Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &area)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	if(!document())
 		return;
 
@@ -674,6 +732,8 @@ void WaveformRendererCairo::draw_marker(Cairo::RefPtr<Cairo::Context> &cr, const
  */
 void WaveformRendererCairo::draw_player_position(Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &area)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	set_color(cr, m_color_player_position);
 
 	int pos = get_pos_by_time(player_time());
@@ -689,6 +749,8 @@ void WaveformRendererCairo::draw_player_position(Cairo::RefPtr<Cairo::Context> &
  */
 void WaveformRendererCairo::display_time_info(Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &area)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	Cairo::TextExtents extents;
 	cr->get_text_extents(SubtitleTime::null(), extents);
 
@@ -724,6 +786,39 @@ void WaveformRendererCairo::display_time_info(Cairo::RefPtr<Cairo::Context> &cr,
 	}
 }
 
+/*
+ */
+void WaveformRendererCairo::draw_keyframes(Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &area)
+{
+	se_debug(SE_DEBUG_WAVEFORM);
+
+	Player *player = SubtitleEditorWindow::get_instance()->get_player();
+	if(player == NULL)
+		return;
+
+	Glib::RefPtr<KeyFrames> keyframes = player->get_keyframes();
+	if(!keyframes)
+		return;
+
+	set_color(cr, m_color_keyframe);
+
+	long start_clip = get_time_by_pos(get_start_area());
+	long end_clip = get_time_by_pos(get_end_area());
+
+	for(KeyFrames::const_iterator it = keyframes->begin(); it != keyframes->end(); ++it)
+	{
+		// display only if it's in the area
+		if(*it < start_clip && *it < end_clip)
+			continue;
+		if(*it > end_clip)
+			break; // the next keyframes are out of the area
+
+		long pos = get_pos_by_time(*it);
+		cr->move_to(pos, 0);
+		cr->line_to(pos, area.get_height());
+		cr->stroke();
+	}
+}
 
 
 
